package com.ruoyi.web.controller.rc;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.system.service.ISysDeptService;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TChapter;
import com.ruoyi.rc.service.ITChapterService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;

/**
 * 章节Controller
 * 
 * @author ruoyi
 * @date 2024-07-24
 */
@RestController
@RequestMapping("/rc/chapter")
public class TChapterController extends BaseController
{
    @Autowired
    private ITChapterService tChapterService;

    @Autowired
    private ISysDeptService deptService;

    /**
     * 查询章节列表
     */
    @GetMapping("/list")
    public AjaxResult list(TChapter tChapter)
    {
        return success(tChapterService.selectTChapterList(tChapter));
    }

    /**
     * 导出章节列表
     */
    @Log(title = "章节", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TChapter tChapter)
    {
        List<TChapter> list = tChapterService.selectTChapterList(tChapter);
        ExcelUtil<TChapter> util = new ExcelUtil<TChapter>(TChapter.class);
        util.exportExcel(response, list, "章节数据");
    }

    /**
     * 获取章节详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tChapterService.selectTChapterById(id));
    }

    /**
     * 新增章节
     */
    @Log(title = "章节", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TChapter tChapter)
    {
        if (StringUtils.isNull(tChapter.getDeptId())) {
            tChapter.setDeptId(getLoginUser().getDeptId().toString());
        }
        return toAjax(tChapterService.insertTChapter(tChapter));
    }

    /**
     * 修改章节
     */
    @Log(title = "章节", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TChapter tChapter)
    {
        return toAjax(tChapterService.updateTChapter(tChapter));
    }

    /**
     * 删除章节
     */
    @Log(title = "章节", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tChapterService.deleteTChapterByIds(ids));
    }
}
